c******************************************************************************
      SUBROUTINE CO2He2dPES(isC,isO,v3,RR,TH,V) 
c******************************************************************************
c** Subroutine to generate values of the vibrationally averaged 2D-MLR analyic
c  potential energy surfaces for complexes formed between He and any of the 
c  four CO2 isotopologues 12C16O2, 13C16O2, 12C18O2 or 13C18O2  in vibrational
c  level v3= 0 or 1, as determined by Hui Li & Robert J. Le Roy 
c  [PCCP, submitted 2008].  On first call, input values of isC, isO & v3 
c  select appropriate 2D-MLR expansion parameters from DATA statements in
c  subroutine PARAREAD2;  subsequent calls generate additional potential
c  function values for that same case.
c** Input variables:
c  isC - 12 or 13 identifies the C isotope 
c  isO - 16 or 18 identifies the O isotope 
c  v3  - 0 or 1 identy the CO2 aymmetric stretch vibrational level  
c  RR  - distance between He and CO2 centre of mass in [Angst]
c  TH  - Jacobi angular coordinate 'theta' in degrees
c** Output:   V [cm-1]  is the calculated interaction energy '\Delta{V}'.
c-----------------------------------------------------------------------------
      INTEGER  MXPARM, NPMAX
      PARAMETER (MXPARM=60, NPMAX=20)
      INTEGER  I,J,K,IP,isC,isO,v3,NPS,IPAR, MMN,NPOW
      REAL*8  RR,TH,V,COSTH,R1, YC,Re,De,Vasy,AREF,AREFp,Rep,PI,
     1  VLRe,dVLRedRe,phiINF,RTPp,yp,ype,yPOW,XP,SUM,DSUM,VLR,XPW
      REAL*8 Pn(0:NPMAX+1),PHI(NPMAX) 
c-----------------------------------------------------------------------
      INTEGER p,NDE,NRE,NCN,MCM,NS,NL, NPHI(NPMAX)
      REAL*8  PV(MXPARM),RREF,CN,RCN2CN,RCMCN,RCM2CN
      COMMON /DATABLKK/PV,RREF,CN,RCN2CN,RCMCN,RCM2CN, p,NDE,NRE,
     1  NCN,MCM,NS,NL,NPHI
c-----------------------------------------------------------------------
      DATA IPAR/0/
      SAVE IPAR
c-----------------------------------------------------------------------------
      IF(IPAR.EQ.0) THEN
          CALL PARAREAD2(isC,isO,v3)
          IPAR= 1
          ENDIF
      PI=DACOS(-1.0D0)
      COSTH=DCOS(TH*PI/180.D0)
      R1=RR
      Pn(0)= 1.d0
      Pn(1)= COSTH
      DO I= 1,NPMAX
          Pn(I+1)=((2.d0*I+1.d0)*COSTH*Pn(I) -
     1                                  DFLOAT(I)*Pn(I-1))/DFLOAT(I+1)
          ENDDO 
c calculate De(theta)
      De=0.0d0
      DO  I= 0,NDE-1
          De= De + Pn(I)*PV(I+1)
          ENDDO
c caculate the Re 
      Re=0.0d0
      IP=NDE
      DO I=0,NRE-1
           IP=IP+1
           Re=Re+Pn(I)*PV(IP)
           ENDDO  
      AREF= RREF
      IF(RREF.LE.0.d0) AREF= Re
      AREFp= AREF**p
      Rep= Re**p
      VLRe= CN*(1.d0+Pn(2)*RCN2CN)/Re**NCN
      dVLRedRe= -NCN*VLRe/Re
      IF(MCM.GT.NCN) THEN
          MMN= MCM - NCN
          IF(p.LE.MMN) MMN= 0
          IF(MMN.GT.0) THEN
              VLRe= (CN/Re**NCN)*(1.d0 + RCN2CN*Pn(2) +
     &                               (RCMCN+RCM2CN*Pn(2))/Re**MMN)
              dVLRedRe= dVLRedRe - MCM*CN*(RCMCN+RCM2CN*Pn(2))/
     &                                                Re**(MCM+1)
              ENDIF
          phiINF= DLOG(2.d0*De/VLRe)
          ENDIF
      RTPp= R1**p
      yp= (RTPp - AREFp)/(RTPp + AREFp)
      ype= (RTPp - Rep)/(RTPp + Rep)
c caculate the PHI(N) 
      NPOW= NS+1
      IF(R1.GE.Re) NPOW= NL+1
      yPOW= 1.d0 - yp
      SUM= 0.0d0
      DSUM= 0.0d0 
      NPS= 0
      IP= NDE+ NRE
      DO  J=1, NPOW
          IP=IP+1
          PHI(J)= PV(IP)*Pn(0)
          DO  K=2,NPHI(J)
              IP=IP+1
              PHI(J)=PHI(J)+ PV(IP)*Pn(K-1)
              ENDDO
          NPS=NPS+NPHI(J)
          SUM=SUM+PHI(J)*yp**(J-1)
          IF(RREF.LE.0.D0) DSUM=DSUM+yPOW*PHI(J)*(J-1)*yp**(J-1)
          ENDDO
c  caculate Vasy 
      IP= NDE+NRE+NPS
      Vasy= PV(IP+1) 
      XP= SUM*yPOW+ phiINF*yp
      VLR= CN*(1.d0 + RCN2CN*Pn(2))/R1**NCN
      IF(MMN.GT.0) THEN
          VLR= (CN/R1**NCN)*(1.d0 + RCN2CN*Pn(2)+
     1                                   (RCMCN+RCM2CN*Pn(2))/R1**MMN)
          ENDIF
      XPW= DEXP(-XP*ype) * VLR/VLRe
      YC= De*(1.d0 - XPW)**2-De+Vasy 
      V=YC
      RETURN
      END
c23456789 123456789 123456789 123456789 123456789 123456789 123456789 12

c******************************************************************************
      SUBROUTINE PARAREAD2(isC,isO,v3)
      PARAMETER (MXPARM=60, NPMAX=20)
      PARAMETER (MXDE=17, MXRE=13, MXPHI=12,ISP=8)
      INTEGER MXPARM, NPMAX,MXDE,MXRE,MXPHI,ISP
      REAL*8   DE(ISP,MXDE),RE(ISP,MXRE),PHIPHI(ISP,MXPHI),
     1                 XCN(ISP),XRCN2CN(ISP),XfDe(ISP),PI,fRe,fDe
      INTEGER I,J,K,IP,isC,isO,v3,isv,NPARM,NPOW, NPS
c-----------------------------------------------------------------------
      INTEGER p,NDE,NRE,NCN,MCM,NS,NL, NPHI(NPMAX)
      REAL*8  PV(MXPARM),RREF,CN,RCN2CN,RCMCN,RCM2CN
      COMMON /DATABLKK/PV,RREF,CN,RCN2CN,RCMCN,RCM2CN, p,NDE,NRE,
     1  NCN,MCM,NS,NL,NPHI
c-----------------------------------------------------------------------
c  input parameters which are the same for all isotopologues
      DATA NDE/17/,NRE/13/ 
      DATA p/3/,NS/3/,NL/3/,RREF/0/,NPOW/4/   
      DATA (NPHI(I),I=1,4)/5,3,3,1/          
      DATA NCN/6/, MCM/8/, RCMCN/4.65d0/,RCM2CN/4.85d0/
      DATA fRe/0.99577d0/
c      DATA fRe/1.0d0/
c-----------------------------------------------------------------------
c  input initial parameters which are changed with different isotope case
      DATA (XCN(I),I=1,ISP)/7.245762d4,7.251069d4,7.245688d4,7.250852d4,
     &                     7.245722d4,7.250952d4,7.245647d4,7.250732d4/
      DATA (XRCN2CN(I),I=1,ISP)/0.2641d0,0.2629d0,0.2641d0,0.2630d0,
     &                     0.2641d0,0.2629d0,0.2641d0,0.2630d0/
      DATA (XfDe(I),I=1,ISP)/1.0d0,0.99842d0,1.0d0,0.99842d0,
     &                       1.0d0,0.99842d0,1.0d0,0.99842d0/
c
c     isC=12, isO=16, v3=0
c
      DATA (DE(1,I),I=1,MXDE)/3.2039D1, 0.0D0, -1.4787D1, 0.0D0,
     1         1.4616D1, 0.0D0, -8.049D0, 0.0D0, 4.315D0, 0.0D0,
     2 -2.135D0, 0.0D0, 9.75D-1, 0.0D0, -4.39D-1, 0.0D0, 1.84D-1/
      DATA (RE(1,I),I=1,MXRE)/3.619D0, 0.0D0, 8.3644D-1, 0.0D0,
     1    -2.6198D-1, 0.0D0, 9.367D-2, 0.0D0, -3.118D-2, 0.0D0,
     2                                 8.3D-3, 0.0D0, -1.42D-3/
      DATA (PHIPHI(1,I),I=1,MXPHI)/3.04D-2, 0.0D0, 1.001D0, 0.0D0,
     1         -1.72D-2, 6.961D-1, 0.0D0, 1.8D-1, -2.35D-1, 0.0D0,
     2                                          -2.03D-1, 1.5D-1/

c     isC=12, isO=16, v3=1

      DATA (DE(2,I),I=1,MXDE)/3.1979D1,0.0D0,-1.4637D1,0.0D0,
     1      1.4559D1, 0.0D0, -7.977D0, 0.0D0, 4.281D0, 0.0D0,
     2 -2.104D0, 0.0D0, 9.64D-1, 0.0D0, -4.57D-1, 0.0D0, 1.93D-1/
      DATA (RE(2,I),I=1,MXRE)/3.62001D0, 0.0D0, 8.3496D-1, 0.0D0,
     1      -2.6246D-1, 0.0D0, 9.341D-2, 0.0D0, -3.117D-2, 0.0D0,
     2                                 8.09D-3, 0.0D0, -1.25D-3/
      DATA (PHIPHI(2,I),I=1,MXPHI)/2.91D-2,0.0D0,1.0003D0,0.0D0,
     1       -1.61D-2, 6.91D-1, 0.0D0, 1.77D-1, -2.37D-1, 0.0D0,
     2                                        -2.04D-1, 1.5D-1/

c     isC=13, isO=16, v3=0

      DATA (DE(3,I),I=1,MXDE)/3.204D1,0.0D0,-1.479D1,0.0D0,
     1      1.4617D1, 0.0D0, -8.05D0, 0.0D0, 4.315D0, 0.0D0,
     2 -2.135D0, 0.0D0, 9.75D-1, 0.0D0,-4.38D-1,0.0D0, 1.84D-1/
      DATA (RE(3,I),I=1,MXRE)/3.61898D0,0.0D0,8.3646D-1,0.0D0,
     1  -2.6196D-1, 0.0D0, 9.368D-2, 0.0D0, -3.118D-2, 0.0D0,
     2                                8.3D-3, 0.0D0, -1.43D-3/
      DATA (PHIPHI(3,I),I=1,MXPHI)/3.05D-2,0.0D0,1.001D0,0.0D0,
     1 -1.73D-2, 6.962D-1, 0.0D0, 1.8D-1, -2.35D-1, 0.0D0,
     2                                        -2.03D-1, 1.5D-1/

c     isC=13, isO=16, v3=1

      DATA (DE(4,I),I=1,MXDE)/3.1982D1,0.0D0,-1.4642D1,0.0D0,
     1        1.4561D1,0.0D0, -7.98D0, 0.0D0, 4.283D0, 0.0D0,
     2  -2.106D0, 0.0D0,9.64D-1, 0.0D0,-4.56D-1,0.0D0,1.93D-1/
      DATA (RE(4,I),I=1,MXRE)/3.61997D0,0.0D0, 8.3501D-1,0.0D0,
     1    -2.6244D-1, 0.0D0, 9.342D-2, 0.0D0,-3.117D-2, 0.0D0,
     2                                8.1D-3, 0.0D0, -1.26D-3/
      DATA (PHIPHI(4,I),I=1,MXPHI)/2.92D-2, 0.0D0,1.0006D0,0.0D0,
     1      -1.61D-2, 6.914D-1, 0.0D0, 1.78D-1, -2.37D-1, 0.0D0,
     2                                        -2.04D-1, 1.5D-1/

c     isC=12, isO=18, v3=0

      DATA (DE(5,I),I=1,MXDE)/3.204D1,0.0D0,-1.4788D1,0.0D0,
     1       1.4616D1,0.0D0, -8.05D0, 0.0D0, 4.315D0, 0.0D0,
     2  -2.135D0, 0.0D0, 9.75D-1, 0.0D0, -4.38D-1,0.0D0,1.84D-1/
      DATA (RE(5,I),I=1,MXRE)/3.61898D0,0.0D0,8.3645D-1,0.0D0,
     1  -2.6196D-1, 0.0D0, 9.367D-2, 0.0D0, -3.119D-2,0.0D0,
     2                                 8.3D-3, 0.0D0, -1.42D-3/
      DATA (PHIPHI(5,I),I=1,MXPHI)/3.05D-2,0.0D0, 1.001D0, 0.0D0,
     1    -1.73D-2, 6.962D-1, 0.0D0, 1.8D-1, -2.35D-1, 0.0D0,
     2                                         -2.03D-1, 1.5D-1/

c     isC=12, isO=18, v3=1

      DATA (DE(6,I),I=1,MXDE)/3.1981D1,0.0D0,-1.464D1,0.0D0,
     1          1.456D1,0.0D0,-7.979D0,0.0D0,4.282D0, 0.0D0,
     2  -2.105D0,0.0D0,9.63D-1,0.0D0,-4.56D-1, 0.0D0,1.93D-1/
      DATA (RE(6,I),I=1,MXRE)/3.61998D0,0.0D0,8.3499D-1,0.0D0,
     1  -2.6245D-1, 0.0D0, 9.342D-2, 0.0D0, -3.117D-2, 0.0D0,
     2                               8.1D-3, 0.0D0, -1.26D-3/
      DATA (PHIPHI(6,I),I=1,MXPHI)/2.92D-2,0.0D0,1.0003D0,0.0D0,
     1   -1.61D-2, 6.911D-1, 0.0D0, 1.77D-1,-2.37D-1,0.0D0,
     2                                      -2.04D-1, 1.5D-1/

c    isC=13, isO=18, v3=0

      DATA (DE(7,I),I=1,MXDE)/3.2041D1,0.0D0,-1.479D1,0.0D0,
     1     1.4617D1, 0.0D0, -8.051D0, 0.0D0, 4.316D0,0.0D0,
     2  -2.136D0,0.0D0,9.75D-1,0.0D0,-4.38D-1, 0.0D0,1.84D-1/
      DATA (RE(7,I),I=1,MXRE)/3.61897D0,0.0D0,8.3647D-1,0.0D0,
     1     -2.6195D-1, 0.0D0,9.368D-2, 0.0D0,-3.118D-2,0.0D0,
     2                               8.3D-3, 0.0D0, -1.43D-3/
      DATA (PHIPHI(7,I),I=1,MXPHI)/3.05D-2,0.0D0,1.001D0,0.0D0,
     1       -1.73D-2, 6.962D-1, 0.0D0, 1.8D-1, -2.35D-1,0.0D0,
     2                                       -2.03D-1,1.5D-1/

c     isC=13, isO=18, v3=1

      DATA (DE(8,I),I=1,MXDE)/3.1983D1,0.0D0,-1.4646D1,0.0D0,
     1    1.4562D1, 0.0D0, -7.982D0, 0.0D0, 4.284D0, 0.0D0,
     2  -2.106D0, 0.0D0, 9.64D-1,0.0D0,-4.56D-1, 0.0D0,1.93D-1/
      DATA (RE(8,I),I=1,MXRE)/3.61994D0,0.0D0,8.3504D-1,0.0D0,
     1  -2.6242D-1, 0.0D0, 9.343D-2,0.0D0, -3.117D-2, 0.0D0,
     2                               8.11D-3, 0.0D0, -1.27D-3/
      DATA (PHIPHI(8,I),I=1,MXPHI)/2.93D-2,0.0D0,1.0006D0,0.0D0,
     1       -1.62D-2,6.915D-1, 0.0D0, 1.78D-1, -2.37D-1, 0.0D0,
     2                                         -2.04D-1,1.5D-1/

c-----------------------------------------------------------------------
      isv= 0
      IF((isC.EQ.12).and.(isO.EQ.16).and.(v3.EQ.0)) isv= 1
      IF((isC.EQ.12).and.(isO.EQ.16).and.(v3.EQ.1)) isv= 2
      IF((isC.EQ.13).and.(isO.EQ.16).and.(v3.EQ.0)) isv= 3
      IF((isC.EQ.13).and.(isO.EQ.16).and.(v3.EQ.1)) isv= 4
      IF((isC.EQ.12).and.(isO.EQ.18).and.(v3.EQ.0)) isv= 5
      IF((isC.EQ.12).and.(isO.EQ.18).and.(v3.EQ.1)) isv= 6
      IF((isC.EQ.13).and.(isO.EQ.18).and.(v3.EQ.0)) isv= 7
      IF((isC.EQ.13).and.(isO.EQ.18).and.(v3.EQ.1)) isv= 8
      PI=DACOS(-1.0D0)
      IF(isv.GT.0) THEN
          WRITE(6,600) isC,isO,v3
        ELSE 
          WRITE(6,602) isC,isO,v3
          isv= 1
        ENDIF
c... input initial parameters which are changed with different isotope case 
      CN=XCN(isv)
      RCN2CN=XRCN2CN(isv)
      fDe=XfDe(isv)
      DO I=1,NDE
c... first prepare well depth expansion parameters
          PV(I)=DE(isv,I)
          PV(I)=PV(I)*fDe
          ENDDO
      IP=NDE
      DO I=1,NRE
c... next prepare potential minimum position expansion parameters
          IP=IP+1  
          PV(IP)=RE(isv,I)
          PV(IP)=PV(IP)*fRe
          ENDDO
      IP=NDE+NRE
      NPS=0
      K=0
      DO J=1,NPOW
c... then, prepare exponent coefficient \beta_i expansion parameters
          DO I=1,NPHI(J)
              IP=IP+1
              K=K+1
              PV(IP)=PHIPHI(isv,K)
              ENDDO
          NPS=NPS+NPHI(J)
          ENDDO
c** Finally ... (if desired) read shift for definition of energy zero
      IP=NDE+NRE+NPS 
      NPARM=IP+1
      PV(NPARM)=0.0D0
      RETURN
  600 FORMAT(/' Generate 2D-MLRR potential for {',i2,'}C{',i2,'}O2(v3=',
     1  i1,')-{4}He')
  602 FORMAT(/' *** 2D Potential He-CO2 Function selection parameters  i
     1sC=',i2,'   isO=',i3,'   v3=',i2/'   do not match defined cases.'
     2  '  Generate potential for {12}C{16}O2(v=0)-He instead.')
      END 
c***********************************************************************
