c******************************************************************************
      SUBROUTINE CO2He3dPES(RR1,RR2,TH,V) 
c******************************************************************************
c** Subroutine to generate values of the 3D-MLR analyic potential energy
c  surface for CO2+He determined by Li & Le Roy [submitted to .....] by fitting
c  to ab initio points generated at the CCSD(T)/aug-cc-pVQZ level.
c  The parameters defining this potential are stored in DATA statements in
c  subroutine PARAREAD3 (appended below), which is called on First Entry to 
c  this subroutine.
c** Input variables:  
c  RR1 - distance between He and CO2 centre of mass in [Angst]
c  RR2 - asymmetric stretch CO2 normal mode coordinate Q3 in [Angst]
c  TH  - Jacobi angular coordinate 'theta' in degrees
c** Output:   V [cm-1]  is the calculated interaction energy '\Delta{V}'.
c-----------------------------------------------------------------------------
      INTEGER MXPARM, NPMAX
      PARAMETER (MXPARM=200, NPMAX=20)
      REAL*8 COSTH,TH,R1,R2,V,RR1,RR2
      INTEGER I,J,K,IP,p,NDE,NRE,NCN,MCM,MMN,NS,NL,NPOW,
     1  NSDE,NSRE
      INTEGER NPDE(NPMAX),NPRE(NPMAX),NPHI(NPMAX),
     1  NPPHI(NPMAX,NPMAX)
      REAL*8 Pn(0:NPMAX+1),Xn(0:NPMAX+1)
      REAL*8 PDE(NPMAX),PRE(NPMAX),PHI(NPMAX),PPHI(NPMAX,NPMAX)
      REAL*8  YC,Re,De,Vasy,AREF,AREFp,Rep,VLRe,DR,
     1 dVLRedRe,phiINF,RTPp,yp,ype,yPOW,XP,SUM,DSUM,VLR,XPW
c
      REAL*8  PV(MXPARM)
      REAL*8  RREF,RCN2CND,RCMCN,RCM2CN,CNI,CND,CND0,CN,PI,IPAR
      COMMON /DATABLKK/PV,RREF,CND0,RCMCN,RCM2CN,
     1 NPPHI,NPDE,NPRE,NPHI,NDE,NRE,NCN,MCM,NS,NL,p
c-----------------------------------------------------------------------
      REAL*8 BOHR,HATRCM
      COMMON /PHYCONT/BOHR,HATRCM
c-----------------------------------------------------------------------
      DATA IPAR/0/
      SAVE IPAR
c-----------------------------------------------------------------------
      IF(IPAR.EQ.0) THEN
          CALL PARAREAD3
          IPAR= 1
          ENDIF
      PI=DACOS(-1.0D0)
      COSTH=DCOS(TH*PI/180.D0)
      R2=RR2
      R1=RR1
      Pn(0)=1.D0
      Pn(1)=COSTH
      DO I=1,NPMAX
          Pn(I+1)=((2.d0*I+1.d0)*COSTH*Pn(I) -
     1                                  DFLOAT(I)*Pn(I-1))/DFLOAT(I+1)
          ENDDO
      Xn(0)=1.D0
      DO I=0,NPMAX
          Xn(I+1)=Xn(I)*R2
          ENDDO
c caculate De 
      IP=0
      NSDE=0
      De=0.0d0
      DO I=1,NDE
          PDE(I)=0.0D0
          DO J=1,NPDE(I)
              IP=IP+1
              PDE(I)=PDE(I)+PV(IP)*Xn(J-1)
              ENDDO
          NSDE=NSDE+NPDE(I)
          De=De+PDE(I)*Pn(I-1)
          ENDDO
c caculate the Re 
      IP=NSDE
      NSRE=0
      Re=0.0d0
      DO I=1,NRE
          PRE(I)=0.0D0
          DO J=1,NPRE(I)
              IP=IP+1
              PRE(I)=PRE(I)+PV(IP)*Xn(J-1)
              ENDDO
          NSRE=NSRE+NPRE(I)
          Re=Re+PRE(I)*Pn(I-1)
          ENDDO
      AREF= RREF
      IF(RREF.LE.0.d0) AREF= Re
      AREFp= AREF**p
      Rep= Re**p
      DR=R2*SQRT(2.0)/BOHR
c  C_6=C_6(ind)+C_6(dis)
c  C_6(ind)=u^2(CO2)*alf(He)*(1+p2) Russell T. Pack JCP 64,1659(1976)
c  the new u and alf value come from George Maroulis CPL, 417, 235 (2006)
      CNI= (-1.21d0*DR+0.02d0*DR**3)**2
     1                           *1.383112d0*HATRCM*BOHR**6 *(1+Pn(2))
      CND= CND0*((17.5372d0+0.34d0*DR**2-0.33d0*DR**4)/17.5372d0)
c  C_6(2,dis)/C_6(0,dis)=(alf(||)-alf(+))/(alf(||)+2*alf(+))
c               =deta(alf)/(3*aver(alf))  JCP 105,9130(1996)
      RCN2CND=(13.9222d0-2.93d0*DR**2-1.d0*DR**4)/
     &                    (3.d0*(17.5372d0+0.34d0*DR**2-0.33d0*DR**4))
      CN=CNI+CND*(1.+Pn(2)*RCN2CND)
      VLRe= CN/Re**NCN
      dVLRedRe= -NCN*VLRe/Re
      IF(MCM.GT.NCN) THEN
          MMN= MCM - NCN
          IF(p.LE.MMN) MMN= 0
          IF(MMN.GT.0) THEN
              VLRe= (CN/Re**NCN)*(1.d0 + (RCMCN+RCM2CN*Pn(2))/Re**MMN)
              dVLRedRe= dVLRedRe-MCM*CN*(RCMCN+RCM2CN*Pn(2))/Re**(MCM+1)
              ENDIF
          phiINF= DLOG(2.d0*De/VLRe)
          ENDIF
      RTPp= R1**p
      yp= (RTPp - AREFp)/(RTPp + AREFp)
      ype= (RTPp - Rep)/(RTPp + Rep)
c caculate the PHI(N) 
      NPOW= NS+1
      IF(R1.GE.Re) NPOW= NL+1
      yPOW= 1.d0 - yp
      SUM=0.d0
      DSUM=0.d0
      IP=NSDE+NSRE
      DO I=1,NPOW
          PHI(I)=0.0D0
          DO J=1,NPHI(I)
              PPHI(I,J)=0.0D0
              DO K=1, NPPHI(I,J)
                  IP=IP+1
                  PPHI(I,J)=PPHI(I,J)+PV(IP)*Xn(K-1)
                  ENDDO
              PHI(I)=PHI(I)+PPHI(I,J)*Pn(J-1)
              ENDDO
          SUM=SUM+PHI(I)*yp**(I-1)
          IF(RREF.LE.0.D0) DSUM=DSUM+yPOW*PHI(I)*(I-1)*yp**(I-1)
          ENDDO
c caculate Vasy
      Vasy=PV(IP+1)
c total potential
      XP= SUM*yPOW+ phiINF*yp
      VLR= CN/R1**NCN
      IF(MMN.GT.0) THEN
          VLR=(CN/R1**NCN)*(1.d0 + (RCMCN+RCM2CN*Pn(2))/R1**MMN)
          ENDIF
      XPW= DEXP(-XP*ype) * VLR/VLRe
      YC= De*(1.d0 - XPW)**2-De+Vasy
      V=YC
c     WRITE(11,661)TH,R1,V
c 661 FORMAT(1x,2F9.4,F15.7)
       END
c23456789 123456789 123456789 123456789 123456789 123456789 123456789 12

c************************************************************************
      SUBROUTINE PARAREAD3
c** On first call to CO2HePES, this subroutine selects the CO2-He potential
c  function expansion parameters from the DATA statements and incorporatpes
c  morphing parameter
      INTEGER   MXPARM, NPMAX,MXDE,MXRE,MXPHI
      PARAMETER (MXPARM=200, NPMAX=20)
      PARAMETER (MXDE=39, MXRE=27, MXPHI=19)
      REAL*8  DE(MXDE),RE(MXRE),PHIPHI(MXPHI)
c-----------------------------------------------------------------------
      INTEGER I,J,K,L,IP,p,NDE,NRE,NCN,MCM,NS,NL,NPOW,
     1  NSDE,NSRE,NPARM
      INTEGER NPDE(NPMAX),NPRE(NPMAX),NPHI(NPMAX),
     1  NPPHI(NPMAX,NPMAX)
      REAL*8  PV(MXPARM)
      REAL*8  RREF,RCMCN,RCM2CN,CND0,PI,fRe,fDe
      COMMON /DATABLKK/PV,RREF,CND0,RCMCN,RCM2CN,
     1 NPPHI,NPDE,NPRE,NPHI,NDE,NRE,NCN,MCM,NS,NL,p
c-----------------------------------------------------------------------
      REAL*8 BOHR,HATRCM
      COMMON /PHYCONT/BOHR,HATRCM
      DATA BOHR/0.5291772108D0/,HATRCM/219474.6313705d0/
c-----------------------------------------------------------------------
      PI=DACOS(-1.0D0)
c     input initial parameters 
      DATA NDE/17/, NRE/13/
      DATA (NPDE(I),I=1,17)/3,2,3,2,3,2,3,2,3,2,3,2,3,2,1,2,1/ 
      DATA (NPRE(I),I=1,13)/3,2,3,2,3,2,3,2,1,2,1,2,1/ 
      DATA p/3/, NS/3/, NL/3/, RREF/0/,NPOW/4/
      DATA (NPHI(I),I=1,4)/5,3,3,3/
      DATA (NPPHI(1,J),J=1,5)/1,2,1,2,1/ 
      DATA (NPPHI(2,J),J=1,3)/1,2,1/
      DATA (NPPHI(3,J),J=1,3)/1,2,1/
      DATA (NPPHI(4,J),J=1,3)/1,2,1/
      DATA NCN/6/,CND0/7.2431d4/, MCM/8/, RCMCN/4.65d0/,RCM2CN/4.85d0/
      DATA fRe/1.0d0/,fDe/1.0d0/
c      DATA fRe/0.99577d0/,fDe/1.0d0/
      DATA (DE(I),I=1,MXDE)/32.07, 0.0D0,2.8D0,0.0D0,-1.043D1,
     1                   -1.4849D1,0.0D0,2.54D1,0.0D0,4.945D1,
     2                   1.4646D1,0.0D0,-3.3D1,0.0D0,-3.147D1,
     3                   -8.086D0, 0.0D0, 5.2D1,0.0D0, 2.37D1,
     4                    4.332D0, 0.0D0,-3.5D1,0.0D0,-1.35D1,
     5                     -2.15D0, 0.0D0, 2.7D1, 0.0D0,7.3D0,
     6                     9.8D-1, 0.0D0,-1.3D1, 0.0D0,-3.8D0,
     7                          -4.3D-1, 0.0D0, 1.5D0, 1.8D-1/
      DATA (RE(I),I=1,MXRE)/3.61855D0,0.0D0,1.46D-1,0.0D0,5.637D-1, 
     1                    8.3738D-1,0.0D0,-4.89D-1,0.0D0,-8.476D-1, 
     2                   -2.619D-1, 0.0D0, 2.1D-1, 0.0D0, 2.919D-1, 
     3                    9.393D-2, 0.0D0, -2.0D-1,0.0D0, -1.19D-1, 
     4                     -3.12D-2, 0.0D0, 1.4D-2, 8.4D-3, 0.0D0, 
     5                                            9.0D-3, -1.50D-3/ 
      DATA(PHIPHI(I),I=1,MXPHI)/3.08D-2,0.0D0,-3.04D-1,9.402D-1,0.0D0,  
     1                          1.1D-1,-1.9D-2,7.1D-1,0.0D0,-7.4D-1,  
     2                       2.53D-1,-2.37D-1,0.0D0,-4.0D-1,-2.1D-1,  
     3                                  7.0D-2,0.0D0,-1.9D0,-2.9D-1/  
c---------------------------------------------------------------------- 
      WRITE(6,600)
      IP=0
      NSDE=0
      DO I=1,NDE
c... first read well depth expansion parameters
          DO J=1,NPDE(I)
              IP=IP+1
              PV(IP)= DE(IP)*fDe
              ENDDO
          NSDE=NSDE+NPDE(I) 
          ENDDO
      IP=NSDE
      NSRE=0
      K=0
      DO I=1,NRE
c... next read minimum position expansion parameters
          DO J=1,NPRE(I)
              IP=IP+1  
              K=K+1
              PV(IP)=RE(K)*fRe
              ENDDO
          NSRE=NSRE+NPRE(I)
          ENDDO 
      IP=NSDE+NSRE
      L=0
      DO I=1,NPOW
c... then, read exponent coefficient \beta_i expansion parameters
          DO J=1,NPHI(I)
              DO K=1,NPPHI(I,J)
                  IP=IP+1
                  L=L+1
                  PV(IP)=PHIPHI(L)
                  ENDDO
              ENDDO
          ENDDO 
c** Finally ... (if desired) read shift for definition of energy zero
      NPARM=IP+1
      PV(NPARM)=0.0D0
      RETURN
  600 FORMAT(/' Generate 3D-MLR CO2-He potential energy surface of Hui',
     1 ' Li & R.J. Le Roy. [PCCP, submitted 2008]')
      END
c***********************************************************************

 
